@@ -284,6 +284,11 @@ file_sel_response_cb (GtkWidget   *w,
 		window->folder_to_view = g_strdup (extract_to_dir);
 	}
 
+	if (password != NULL) {
+		g_free (window->password);
+		window->password = g_strdup (password);
+	}
+
 	window_archive_extract (window,
 				file_list,
 				extract_to_dir,
@@ -353,7 +358,7 @@ create_extra_widget (DialogData *data)
 	tooltips = gtk_tooltips_new ();
 	
 	vbox1 = gtk_vbox_new (FALSE, 6);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox1), 6);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox1), 0);
 
 	hbox28 = gtk_hbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox28, TRUE, TRUE, 0);
@@ -478,13 +483,12 @@ dlg_extract (GtkWidget *widget,
 	data->dialog = gtk_file_chooser_dialog_new (
 				    _("Extract"),
 				    GTK_WINDOW (data->window->app),
-				    GTK_FILE_CHOOSER_ACTION_SAVE,
+				    GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
 				    GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 				    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				    FR_STOCK_EXTRACT, GTK_RESPONSE_OK,
 				    NULL);
 	file_sel = GTK_FILE_CHOOSER (data->dialog);
-	gtk_file_chooser_set_folder_mode (file_sel, TRUE);
 	gtk_file_chooser_set_select_multiple (file_sel, FALSE);
 	gtk_file_chooser_set_local_only (file_sel, TRUE);
 
